@@ -85,7 +85,10 @@ def parse_query_param(url, param):
         The value of the parameter.
     """
     
-    return parse.parse_qs(parse.urlparse(url).query)[param][0]
+    try:
+        return parse.parse_qs(parse.urlparse(url).query)[param][0]
+    except:
+        return None
 
 def unicodize(text):
     return re.sub(r'\\u([0-9A-Fa-f][0-9A-Fa-f][0-9A-Fa-f][0-9A-Fa-f])', lambda x: chr(int(x.group(0)[2:], 16)), text)
@@ -106,11 +109,7 @@ def filenameable(text):
         0: None,
         ord('/'): '-',
     })
-    if platform.system() == 'Darwin': # For Mac OS
-        text = text.translate({
-            ord(':'): '-',
-        })
-    elif platform.system() == 'Windows': # For Windows
+    if platform.system() == 'Windows': # For Windows
         text = text.translate({
             ord(':'): '-',
             ord('*'): '-',
@@ -124,6 +123,13 @@ def filenameable(text):
             ord('['): '(',
             ord(']'): ')',
         })
+    else:
+        if text.startswith("."):
+            text = text[1:]
+        if platform.system() == 'Darwin': # For Mac OS
+            text = text.translate({
+                ord(':'): '-',
+            })
     return text
 
 def unescape_html(html):
@@ -146,7 +152,8 @@ def undeflate(data):
     (the zlib compression is used.)
     """
     import zlib
-    return zlib.decompress(data, -zlib.MAX_WBITS)
+    decompressobj = zlib.decompressobj(-zlib.MAX_WBITS)
+    return decompressobj.decompress(data)+decompressobj.flush()
 
 # DEPRECATED in favor of get_content()
 def get_response(url, faker = False):
@@ -551,19 +558,18 @@ def download_urls(urls, title, ext, total_size, output_dir = '.', refer = None,
             
         elif ext == 'mp4':
             try:
-                from .processor.join_mp4 import concat_mp4
-                concat_mp4(parts, os.path.join(output_dir, title + '.mp4'))
-                for part in parts:
-                    os.remove(part)
-            except:
                 from .processor.ffmpeg import has_ffmpeg_installed
                 if has_ffmpeg_installed():
                     from .processor.ffmpeg import ffmpeg_concat_mp4_to_mp4
                     ffmpeg_concat_mp4_to_mp4(parts, os.path.join(output_dir, title + '.mp4'))
-                    for part in parts:
-                        os.remove(part)
                 else:
-                    print('No ffmpeg is found. Merging aborted.')
+                    from .processor.join_mp4 import concat_mp4
+                    concat_mp4(parts, os.path.join(output_dir, title + '.mp4'))
+            except:
+                raise
+            else:
+                for part in parts:
+                    os.remove(part)
             
         else:
             print("Can't merge %s files" % ext)
@@ -729,8 +735,18 @@ def download_main(download, download_playlist, urls, playlist, output_dir, merge
         else:
             download(url, output_dir = output_dir, merge = merge, info_only = info_only)
 
+def get_version():
+    try:
+        import subprocess
+        real_dir = os.path.dirname(os.path.realpath(__file__))
+        git_hash = subprocess.Popen(['git', 'rev-parse', '--short', 'HEAD'], cwd=real_dir, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL).stdout.read().decode('utf-8').strip()
+        assert git_hash
+        return '%s-%s' % (__version__, git_hash)
+    except:
+        return __version__
+
 def script_main(script_name, download, download_playlist = None):
-    version = 'You-Get %s, a video downloader.' % __version__
+    version = 'You-Get %s, a video downloader.' % get_version()
     help = 'Usage: %s [OPTION]... [URL]...\n' % script_name
     help += '''\nStartup options:
     -V | --version                           Display the version and exit.
